Learn R Programming

FiRE (version 1.0.1)

fit: Hash samples in bins

Description

Hashing samples into bins, using Sketching as hash function. This function repeats hashing process L times by sampling M dimensions at a time and hashes samples into one of H bins.

Arguments

data

On which rarity score needs to be computed. Required to be a matrix. (can be converted to matrix with as.matrix)

Details

For usage see example.

Examples

Run this code
# NOT RUN {
  
# }
# NOT RUN {
     ## Creating class object with required arguments
     model <- new(FiRE::FiRE, L, M)
     model$fit(data)

  
# }

Run the code above in your browser using DataLab